__author__ = """Francesco Ranaudo"""
__email__ = 'francesco.ranaudo@gmail.com'
__version__ = '0.5.0'

import os

HERE = os.path.dirname(__file__)

HOME = os.path.abspath(os.path.join(HERE, '../../'))
DATA = os.path.abspath(os.path.join(HOME, 'data'))
DOCS = os.path.abspath(os.path.join(HOME, 'docs'))
TEMP = os.path.abspath(os.path.join(HOME, 'temp'))
