# import time
# import schedule
# def report():
#     my_balance = 10   ## Replace this number with an API call to fetch your account balance
#     my_message = "Current balance is: {}".format(my_balance)   ## Customize your message
#     telegram_bot_sendtext(my_message)
# schedule.every().day.at("12:00").do(report)
# while True:
#     schedule.run_pending()
#     time.sleep(1)
